Crate kcr_executor_testkube_io

Crate kcr_executor_testkube_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the executor.testkube.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

executor.testkube.io/v1

  • Executor
  • Webhook

Modules

v1